"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'cc-lvs'
__description__ = 'cc-lvs - LVS Agent API'
__version__ = '1.0.0'
__author__ = 'Cockroach Creative'
__author_email__ = 'support@cockreative.com'
__license__ = 'Apache 2.0'
__url__ = 'https://cockreative.com/'
